@@ -3,7 +3,7 @@ BEGIN {
   $WWW::DuckDuckGo::Link::AUTHORITY = 'cpan:DDG';
 }
 {
-  $WWW::DuckDuckGo::Link::VERSION = '0.015';
+  $WWW::DuckDuckGo::Link::VERSION = '0.016';
 }
 # ABSTRACT: A DuckDuckGo Link definition
 
@@ -45,8 +45,8 @@ has text => (
 
 1;
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -55,7 +55,7 @@ WWW::DuckDuckGo::Link - A DuckDuckGo Link definition
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 SYNOPSIS
 
@@ -118,7 +118,7 @@ Issue Tracker
 
 =item *
 
-Torsten Raudssus <torsten@raudssus.de>
+Torsten Raudssus <torsten@raudss.us> L<https://raudss.us/>
 
 =item *
 
@@ -134,4 +134,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
