@@ -3,7 +3,7 @@ BEGIN {
   $WWW::DuckDuckGo::ZeroClickInfo::AUTHORITY = 'cpan:DDG';
 }
 {
-  $WWW::DuckDuckGo::ZeroClickInfo::VERSION = '0.015';
+  $WWW::DuckDuckGo::ZeroClickInfo::VERSION = '0.016';
 }
 # ABSTRACT: A DuckDuckGo Zero Click Info definition
 
@@ -179,8 +179,8 @@ sub type_long {
 
 1;
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -189,7 +189,7 @@ WWW::DuckDuckGo::ZeroClickInfo - A DuckDuckGo Zero Click Info definition
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 SYNOPSIS
 
@@ -333,7 +333,7 @@ Issue Tracker
 
 =item *
 
-Torsten Raudssus <torsten@raudssus.de>
+Torsten Raudssus <torsten@raudss.us> L<https://raudss.us/>
 
 =item *
 
@@ -349,4 +349,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
